@@ -5,9 +5,7 @@ from .lib.args import get_args
 
 def main():
     args = get_args("GitLab")
-    args.add_argument(
-        "-g", "--groups", metavar=("GROUP"), nargs="+", help="gitlab group names",
-    )
+    args.add_argument("-g", "--groups", nargs="+", help="gitlab group names")
     args = args.parse_args()
     mklog(args.verbosity)
     config = get_config("GitLab")
@@ -31,9 +29,15 @@ def main():
             output = gitlab.batch_run(gitlab.clone_or_pull, repos)
         elif args.command == "status":
             output = gitlab.batch_run(gitlab.status, repos)
+        elif args.command == "jobs":
+            output = gitlab.get_last_failed_jobs(repos)
+        elif args.command == "schedules":
+            output = gitlab.get_pipeline_schedules(repos)
 
-        if output:
+        if type(output) is list:
             print("\n".join(output))
+        else:
+            print(output)
 
 
 if __name__ == "__main__":
