@@ -1,13 +1,15 @@
-import os
+import json
 import logging
+import os
+import readline
 import requests
 import subprocess
 import sys
 import site
+
 from configparser import ConfigParser, ParsingError
 from chopt import chopt
 from subprocess import call
-import readline
 
 if os.name == "posix":
     from .color import ansi_color as color
@@ -17,7 +19,7 @@ else:
 
 def chkdir(path):
     try:
-        path = os.path.expanduser(path)
+        path = os.path.normpath(os.path.expanduser(path))
         os.makedirs(path, exist_ok=True)
         return path
     except Exception as exc:
@@ -50,6 +52,8 @@ def args_vs_config(args, config):
     else:
         destination = config["destination"]
 
+    destination = chkdir(destination)
+
     if args.token:
         token = args.token
     else:
@@ -140,6 +144,9 @@ def paginated_requests(url, headers, params, results=[]):
                 return paginated_requests(url, headers, params={}, results=results)
             return results
         raise AssertionError(response.reason)
+    except json.decoder.JSONDecodeError:
+        results.append(response.content.decode("utf-8"))
+        return results
     except Exception as exc:
         logging.debug(exc)
         raise exc
